==> payara-embedded-all-4.1.1.164-sources.jar: com/sun/enterprise/security/auth/realm/file/FileRealmUser.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.security.auth.realm.file;

import java.util.*;

import com.sun.enterprise.security.auth.realm.NoSuchRealmException;
import com.sun.enterprise.security.auth.realm.Realm;
import com.sun.enterprise.security.auth.realm.User;
import org.glassfish.security.common.FileRealmHelper;


/**
 * Represents a FileRealm user.
 *
 *
 */
public class FileRealmUser implements User
{    
    FileRealmHelper.User user;
    Hashtable attributes = new Hashtable();
    String realm;
    /**
     * Constructor.
     *
     */
    public FileRealmUser(FileRealmHelper.User user, String realm)
    {
        this.user = user;
        this.realm = realm;
    }
    
    public String[] getGroups() {
        return user.getGroups();
    }
    
    /**
     * Returns the realm with which this user is associated
     *
     * @return Realm name.
     * @exception NoSuchRealmException if the realm associated this user
     *            no longer exist
     *
     */
    @Override
    public Realm getRealm() throws NoSuchRealmException
    {
	return Realm.getInstance(realm);
    }

    /**
     * Return the requested attribute for the user.
     * <P>Not really needed.
     *
     * @param key string identifies the attribute.
     */
    @Override
    public Object getAttribute (String key)
    {
        return attributes.get(key);
    }

    /**
     * Return the names of the supported attributes for this user.
     * <P>Not really needed.
     */
    @Override
    public Enumeration getAttributeNames () {
	return attributes.keys();
    }

    @Override
    public String getName() {
        return user.getName();
    }
}

==> payara-embedded-all-6.2023.12-sources.jar: com/sun/enterprise/security/auth/realm/file/FileRealmUser.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018-2019] [Payara Foundation and/or its affiliates]
package com.sun.enterprise.security.auth.realm.file;

import java.util.Enumeration;
import java.util.Hashtable;

import org.glassfish.security.common.FileRealmStorageManager;

import com.sun.enterprise.security.auth.realm.NoSuchRealmException;
import com.sun.enterprise.security.auth.realm.Realm;
import com.sun.enterprise.security.auth.realm.User;

/**
 * Represents a FileRealm user.
 *
 */
public class FileRealmUser implements User {

    private FileRealmStorageManager.User user;
    private Hashtable<String, Object> attributes = new Hashtable<>();
    private String realm;

    public FileRealmUser(FileRealmStorageManager.User user, String realm) {
        this.user = user;
        this.realm = realm;
    }

    public String[] getGroups() {
        return user.getGroups();
    }

    /**
     * Returns the realm with which this user is associated
     *
     * @return Realm name.
     * @exception NoSuchRealmException if the realm associated this user no longer exist
     *
     */
    @Override
    public Realm getRealm() throws NoSuchRealmException {
        return Realm.getInstance(realm);
    }

    /**
     * Return the requested attribute for the user.
     * <P>
     * Not really needed.
     *
     * @param key string identifies the attribute.
     */
    @Override
    public Object getAttribute(String key) {
        return attributes.get(key);
    }

    /**
     * Return the names of the supported attributes for this user.
     * <P>
     * Not really needed.
     */
    @Override
    public Enumeration<String> getAttributeNames() {
        return attributes.keys();
    }

    @Override
    public String getName() {
        return user.getName();
    }
}
